@@ -6,3 +6,7 @@
 #'
 #' @export
 remove_quoted <- strex::str_remove_quoted
+
+#' @rdname remove_quoted
+#' @export
+str_remove_quoted <- remove_quoted
